==> miniorange_saml-8.x-1.122.tar.gz: miniorange_saml/src/Form/MiniorangeSignonSettings.php <==
<?php
/**
 * @file
 * Contains Login Settings for miniOrange SAML Login Module.
 */

 /**
 * Showing Settings form.
 */
 namespace Drupal\miniorange_saml\Form;

 use Drupal\Core\Form\FormBase;
 use Drupal\miniorange_saml\MiniorangeSAMLConstants;
 use Drupal\miniorange_saml\Utilities;

 class MiniorangeSignonSettings extends FormBase {

  public function getFormId() {
    return 'miniorange_saml_login_setting';
  }

  public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state) {

      global $base_url;

      $form['markup_top'] = array(
         '#markup' => '<div class="mo_saml_table_layout_1"><div id="signon_settings_tab" class="mo_saml_table_layout mo_saml_container">
                       <h2>Signin Settings &nbsp;&nbsp; <a id="Restart_moTour" class="btn btn-primary btn-sm mo_tour_button_float" onclick="Restart_moTour()">Take a Tour</a></h2><hr><br/>
                       <div class="mo_saml_highlight_background_note_1"><b>Note:</b> All the features are available in <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Standard, Premium and Enterprise</a> versions of the module</div><br>'
      );

      Utilities::visual_tour_start($form, $form_state);

      $form['miniorange_saml_force_auth'] = array(
        '#type' => 'checkbox',
        '#title' => t('Protect website against anonymous access'),
        '#description' => t('<b>Note: </b>Users will be redirected to your IdP for login in case user is not logged in and tries to access website.<br><br>'),
        '#disabled' => TRUE,
      );

      $form['miniorange_saml_auto_redirect'] = array(
        '#type' => 'checkbox',
        '#title' => t('Check this option if you want to <b>auto redirect the user to IdP.</b>'),
        '#description' => t('<b>Note:</b> Users will be redirected to your IdP for login when the login page is accessed.<br><br>'),
        '#disabled' => TRUE,
      );

      $form['miniorange_saml_enable_backdoor'] = array(
        '#type' => 'checkbox',
        '#title' => t('Check this option if you want to enable <b>backdoor login.</b>'),
        '#disabled' => TRUE,
        '#description' => t('<b>Note: </b>Checking this option <b>creates a backdoor to login to your website using Drupal credentials</b>
              <br>incase you get locked out of your IdP. <br><b>Note down this URL: <span style="color: #FF0000"><code>We provide backdoor URL in standard, premium & enterprise version of the module.</code></span></b><br><br>'),
      );

      $form['miniorange_saml_default_relaystate'] = array(
        '#type' => 'textfield',
        '#title' => t('Default Redirect URL after login.'),
        '#attributes' => array('style' => 'width:700px; background-color: hsla(0,0%,0%,0.08) !important','placeholder' => 'Enter Default Redirect URL'),
        '#disabled' => TRUE,
        '#suffix' => '<br>',
      );
      $form['miniorange_saml_domain_restriction_checkbox'] = array(
        '#type' => 'checkbox',
        '#title' => t('Check this option if you want  <b>Domain Restriction&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Enterprise</a></b>'),
        '#disabled' => TRUE,
      );
      $form['miniorange_saml_set_of_radiobuttons'] = array(
        '#type' => 'fieldset',
          '#states' => array(
            // Only show this field when the checkbox is enabled.
            'visible' => array(
              ':input[name="miniorange_saml_domain_restriction_checkbox"]' => array('checked' => TRUE,'checked'=>FALSE),
            ),
          ),
      );
      $form['miniorange_saml_set_of_radiobuttons']['miniorange_saml_allow_or_block_domains']=array(
          '#type'=>'radios',
          '#maxlength' => 1,
          '#options' => array(  0 => 'I want to allow only some of the domains',1 => 'I want to block some of the domains'),
          '#disabled' => TRUE,

        );

      $form['miniorange_saml_set_of_radiobuttons']['miniorange_saml_domains'] = array(
        '#type' => 'textfield',
        '#title' => t('Enter list of domains'),
        '#attributes' => array('style' => 'width:700px; background-color: hsla(0,0%,0%,0.08) !important',
          'placeholder' => 'Enter semicolon(;) separated domains (Eg. xxxx.com; xxxx.com)'),
        '#disabled' => TRUE,
        '#suffix' => '<br>',

      );
      $form['miniorange_saml_gateway_config_submit'] = array(
        '#type' => 'submit',
        '#value' => t('Save Configuration'),
        '#disabled' => TRUE,
        '#suffix' => '<br><br><br><br><br><br></div>',
      );

      Utilities::spConfigGuide($form, $form_state);
      Utilities::AddSupportButton($form, $form_state);

  return $form;

  }

  public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

  }
 }

==> miniorange_saml-8.x-2.0.tar.gz: miniorange_saml/src/Form/MiniorangeSignonSettings.php <==
<?php
/**
 * @file
 * Contains Login Settings for miniOrange SAML Login Module.
 */

 /**
 * Showing Settings form.
 */
 namespace Drupal\miniorange_saml\Form;

 use Drupal\Core\Form\FormBase;
 use Drupal\miniorange_saml\MiniorangeSAMLConstants;
 use Drupal\miniorange_saml\Utilities;

 class MiniorangeSignonSettings extends FormBase {

  public function getFormId() {
    return 'miniorange_saml_login_setting';
  }

  public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state) {

      global $base_url;

      $form['markup_top'] = array(
         '#markup' => '<div class="mo_saml_table_layout_1"><div id="signon_settings_tab" class="mo_saml_table_layout mo_saml_container">
                       <h2>Signin Settings &nbsp;&nbsp; <a id="Restart_moTour" class="btn btn-primary btn-sm mo_tour_button_float" onclick="Restart_moTour()">Take a Tour</a></h2><hr><br/>
                       <div class="mo_saml_highlight_background_note_1"><b>Note:</b> All the features are available in <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Standard, Premium and Enterprise</a> versions of the module</div><br>'
      );

      Utilities::visual_tour_start($form, $form_state);

      $form['miniorange_saml_disable_autocreate_users'] = array(
          '#type' => 'checkbox',
          '#title' => t('Check this option if you want to disable <b>auto creation</b> of users if user does not exist.'),
          '#disabled' => TRUE,
          '#description'=>t('<b>Note: </b>If you enable this feature new user wont be created, only existing users can login using SSO.<br><br>'),
          '#suffix' => '',
      );

      $form['miniorange_saml_force_auth'] = array(
        '#type' => 'checkbox',
        '#title' => t('Protect website against anonymous access'),
        '#description' => t('<b>Note: </b>Users will be redirected to your IdP for login in case user is not logged in and tries to access website.<br><br>'),
        '#disabled' => TRUE,
      );

      $form['miniorange_saml_auto_redirect'] = array(
        '#type' => 'checkbox',
        '#title' => t('Check this option if you want to <b>auto redirect the user to IdP.</b>'),
        '#description' => t('<b>Note:</b> Users will be redirected to your IdP for login when the login page is accessed.<br><br>'),
        '#disabled' => TRUE,
      );

      $form['miniorange_saml_enable_backdoor'] = array(
        '#type' => 'checkbox',
        '#title' => t('Check this option if you want to enable <b>backdoor login.</b>'),
        '#disabled' => TRUE,
        '#description' => t('<b>Note: </b>Checking this option <b>creates a backdoor to login to your website using Drupal credentials</b>
              <br>incase you get locked out of your IdP. <br><b>Note down this URL: <span style="color: #FF0000"><code>We provide backdoor URL in standard, premium & enterprise version of the module.</code></span></b><br><br>'),
      );

      $form['miniorange_saml_default_relaystate'] = array(
        '#type' => 'textfield',
        '#title' => t('Default Redirect URL after login.'),
        '#attributes' => array('style' => 'width:700px; background-color: hsla(0,0%,0%,0.08) !important','placeholder' => 'Enter Default Redirect URL'),
        '#disabled' => TRUE,
        '#suffix' => '<br>',
      );
      $form['miniorange_saml_domain_restriction_checkbox'] = array(
        '#type' => 'checkbox',
        '#title' => t('Check this option if you want  <b>Domain Restriction&nbsp;<a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">[Enterprise]</a></b>'),
        '#disabled' => TRUE,
      );
      $form['miniorange_saml_set_of_radiobuttons'] = array(
        '#type' => 'fieldset',
          '#states' => array(
            // Only show this field when the checkbox is enabled.
            'visible' => array(
              ':input[name="miniorange_saml_domain_restriction_checkbox"]' => array('checked' => TRUE,'checked'=>FALSE),
            ),
          ),
      );
      $form['miniorange_saml_set_of_radiobuttons']['miniorange_saml_allow_or_block_domains']=array(
          '#type'=>'radios',
          '#maxlength' => 1,
          '#options' => array(  0 => 'I want to allow only some of the domains',1 => 'I want to block some of the domains'),
          '#disabled' => TRUE,

        );

      $form['miniorange_saml_set_of_radiobuttons']['miniorange_saml_domains'] = array(
        '#type' => 'textfield',
        '#title' => t('Enter list of domains'),
        '#attributes' => array('style' => 'width:700px; background-color: hsla(0,0%,0%,0.08) !important',
          'placeholder' => 'Enter semicolon(;) separated domains (Eg. xxxx.com; xxxx.com)'),
        '#disabled' => TRUE,
        '#suffix' => '<br>',

      );
      $form['miniorange_saml_gateway_config_submit'] = array(
        '#type' => 'submit',
        '#value' => t('Save Configuration'),
        '#disabled' => TRUE,
        '#suffix' => '<br><br></div>',
      );

      Utilities::spConfigGuide($form, $form_state);
      Utilities::AddSupportButton($form, $form_state);

  return $form;

  }

  public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

  }
 }
